@@ -3,7 +3,10 @@
 #'
 #' @description Conducts pairwise two-sample permutation tests
 #'              for symmetry across groups.
-#' 
+#'              
+#' @param formula A formula indicating the measurement variable and
+#'                the grouping variable. e.g. y ~ group.
+#' @param data   The data frame to use.
 #' @param x      The response variable as a vector.
 #' @param g      The grouping variable as a vector.
 #' @param b      The blocking variable as a vector.
@@ -12,7 +15,10 @@
 #' @param ...    Additional arguments passed to
 #'               \code{\link{symmetry_test}}.               
 #'             
-#' @details Permutation tests are non-parametric tests 
+#' @details The input should include either \code{formula} and \code{data};
+#'          or \code{x}, \code{g}, and \code{b}.
+#'          
+#'          Permutation tests are non-parametric tests 
 #'          that do not assume normally-distributed errors.
 #'          See \url{http://rcompanion.org/rcompanion/d_06a.html} for
 #'          futher discussion of this test.
@@ -31,17 +37,24 @@
 #'         A matrix of p-values;
 #'         the p-value adjustment method;
 #'         a matrix of adjusted p-values. 
+#'      
+#' @note    The parsing of the formula is simplistic. 
+#'          The first variable on the
+#'          left side is used as the measurement variable.  
+#'          The first variable on the
+#'          right side is used for the grouping variable.
+#'          The second variable on the
+#'          right side is used for the blocking variable.   
 #'         
 #' @examples
 #' data(BobBelcher)
-#' BobBelcher$Instructor = factor(BobBelcher$Instructor, 
-#'                         levels=c("Linda Belcher", "Louise Belcher",
-#'                                  "Tina Belcher", "Bob Belcher",
-#'                                  "Gene Belcher"))
+#' BobBelcher$Instructor = factor( BobBelcher$Instructor, 
+#'                   levels = c("Linda Belcher", "Louise Belcher",
+#'                              "Tina Belcher", "Bob Belcher",
+#'                              "Gene Belcher"))
 #' BobBelcher$Likert.f = factor(BobBelcher$Likert, ordered=TRUE)
-#' PT = pairwisePermutationSymmetryMatrix(x      = BobBelcher$Likert.f,
-#'                                        g      = BobBelcher$Instructor,
-#'                                        b      = BobBelcher$Rater,
+#' PT = pairwisePermutationSymmetryMatrix(Likert.f ~ Instructor | Rater,
+#'                                        data   = BobBelcher,
 #'                                        method = "fdr")$Adjusted
 #' PT
 #' library(multcompView)
@@ -56,8 +69,15 @@
 #' @export  
 
 pairwisePermutationSymmetryMatrix = 
-  function(x, g, b, method = "fdr", ...)
+  function(formula=NULL, data=NULL,
+           x=NULL, g=NULL, b=NULL, 
+           method = "fdr", ...)
   {
+  if(!is.null(formula)){
+    x  = eval(parse(text=paste0("data","$",all.vars(formula[[2]])[1])))
+    g  = eval(parse(text=paste0("data","$",all.vars(formula[[3]])[1])))
+    b  = eval(parse(text=paste0("data","$",all.vars(formula[[3]])[2])))
+    }
   if(!is.factor(g)){g=factor(g)}
   if(!is.factor(b)){g=factor(b)}
   n = length(levels(g))
